diff --git a/checkin_notes b/checkin_notes
index 90c1cb3c8e..fc14613df6 100644
--- a/checkin_notes
+++ b/checkin_notes
@@ -8144,3 +8144,9 @@ David 7 Oct 2008
file_names.h
file_xfer.cpp
time_stats.cpp
+
+David 7 Oct 2008
+ - added a script (from Nicolas) to generate en.po
+
+ html/ops
+ build_po.php
diff --git a/html/ops/build_po.php b/html/ops/build_po.php
new file mode 100755
index 0000000000..af0837d135
--- /dev/null
+++ b/html/ops/build_po.php
@@ -0,0 +1,45 @@
+#!/usr/bin/php
+\\n"
+"POT-Creation-Date: $date\\n"
+"Last-Translator: Generated automatically from source files\\n"
+"MIME-Version: 1.0\\n"
+"Content-Type: text/plain; charset=utf-8\\n"
+"Content-Transfer-Encoding: 8bit\\n"
+"X-Poedit-SourceCharset: utf-8\\n"
+
+msgid "LANG_NAME_NATIVE"
+msgstr "English"
+
+msgid "LANG_NAME_INTERNATIONAL"
+msgstr "English"
+
+
+HDR;
+
+$out = fopen("$path/html/languages/translations/web.pot", "w");
+fwrite($out, $header);
+$pipe = popen("xgettext --omit-header -o - --keyword=tra -L PHP --no-location $path/html/inc/*.inc $path/html/user/*.php $path/html/project.sample/*.*", "r");
+stream_copy_to_stream($pipe, $out);
+fclose($pipe);
+fclose($out);
+
+system("msgen -o $path/html/languages/translations/en.po $path/html/languages/translations/web.pot");
+?>
diff --git a/sched/delete_file.cpp b/sched/delete_file.cpp
index 77475f4676..d61592a4b0 100644
--- a/sched/delete_file.cpp
+++ b/sched/delete_file.cpp
@@ -16,8 +16,7 @@
// along with BOINC. If not, see .
// delete_file [-host_id host_id -file_name file_name]
// -host_id number of host to upload from
// or 'all' if for all active hosts
// -file_name name of the file to delete
//
// Create a msg_to_host_that requests that the host delete the
@@ -39,6 +38,15 @@
#include "sched_config.h"
#include "sched_util.h"
+void usage(char** argv) {
+ fprintf(stderr,
+ "Arrange to delete a file from a host.\n\n"
+ "Usage: %s -host_id H -file_name F\n",
+ argv[0]
+ );
+ exit(0);
+}
+
int delete_host_file(int host_id, const char* file_name) {
DB_MSG_TO_HOST mth;
int retval;
@@ -66,30 +74,22 @@ int main(int argc, char** argv) {
check_stop_daemons();
- for(i=1; i
@@ -16,8 +16,7 @@
// along with BOINC. If not, see .
// delete_file [-host_id host_id -file_name file_name]
-// -host_id number of host to upload from
-// or 'all' if for all active hosts
+// -host_id number of host to delete file from
// -file_name name of the file to delete
//